@@ -151,7 +151,6 @@ void ExerciseWindow::showHistory()
 void ExerciseWindow::showSettings()
 {
     sw = new SettingsWindow(this);
-    sw->load();
     sw->show();
 }
 
@@ -320,7 +319,7 @@ void ExerciseWindow::shaked()
             //QDBusConnection::sessionBus().send(resume);
 
         }
-
+        wd = new WeightDialog(this);
         wd->load(currentExercise, currentGroup, currentReps);
         wd->show();
         if(!exercises.isEmpty())
