@@ -93,14 +93,14 @@ void InfoWindow::orientationChanged()
 
     if(i == 1)
     {
-        str = "/home/user/MyDocs/" + exerciseName + "1.png";
+        str = "/home/user/.qexercise/Images" + exerciseName + "1.png";
         str.replace(QString(" "), QString(""));
 
         bild.load(str);
     }
     else if(i == 2)
     {
-        str = "/home/user/MyDocs/" + exerciseName + "2.png";
+        str = "/home/user/.qexercise/Images/" + exerciseName + "2.png";
         str.replace(QString(" "), QString(""));
 
         bild.load(str);
@@ -127,7 +127,6 @@ void InfoWindow::showHistory()
 void InfoWindow::showSettings()
 {
     sw = new SettingsWindow(this);
-    sw->load();
     sw->show();
 }
 
@@ -270,6 +269,7 @@ void InfoWindow::startExercise()
 
 void InfoWindow::forward()
 {
+    QString str;
     if(i == 2)
     {
         i = 0;
@@ -286,7 +286,16 @@ void InfoWindow::forward()
         //if(info[2] != "")
         //{
             QPixmap bild(w,h);
-            bild.load("/home/user/.qexercise/Images" + exerciseName + "2.png");
+            str = "/home/user/.qexercise/Images/" + exerciseName + "2.png";
+            str.replace(QString(" "), QString(""));
+
+            bild.load(str);
+            if(!bild.load(str))
+            {
+                i = 2;
+                forward();
+                return;
+            }
             bild = bild.scaled(w,h,Qt::KeepAspectRatio);
             lblInfo->setAlignment(Qt::AlignCenter);
             lblInfo->setPixmap(bild);
@@ -304,7 +313,16 @@ void InfoWindow::forward()
             gLayout->addWidget(lblInfo);
             lblInfo->show();
             QPixmap bild(w,h);
-            bild.load("/home/user/.qexercise/Images" + exerciseName + "1.png");
+            str = "/home/user/.qexercise/Images/" + exerciseName + "1.png";
+            str.replace(QString(" "), QString(""));
+
+            bild.load(str);
+            if(!bild.load(str))
+            {
+                i = 1;
+                forward();
+                return;
+            }
             bild = bild.scaled(w,h,Qt::KeepAspectRatio);
             lblInfo->setAlignment(Qt::AlignCenter);
             lblInfo->setPixmap(bild);
@@ -316,6 +334,7 @@ void InfoWindow::forward()
 
 void InfoWindow::back()
 {
+    QString str;
     if(i == 0)
     {
         //if(info[2] != "")
@@ -325,7 +344,16 @@ void InfoWindow::back()
             gLayout->addWidget(lblInfo);
             lblInfo->show();
             QPixmap bild(w,h);
-            bild.load("/home/user/.qexercise/Images" + exerciseName + "2.png");
+            str = "/home/user/.qexercise/Images/" + exerciseName + "2.png";
+            str.replace(QString(" "), QString(""));
+
+            bild.load(str);
+            if(!bild.load(str))
+            {
+                i = 2;
+                back();
+                return;
+            }
             bild = bild.scaled(w,h,Qt::KeepAspectRatio);
             lblInfo->setAlignment(Qt::AlignCenter);
             lblInfo->setPixmap(bild);
@@ -349,7 +377,15 @@ void InfoWindow::back()
         //if(info[1] != "")
         //{
             QPixmap bild(w,h);
-            bild.load("/home/user/.qexercise/Images" + exerciseName + "1.png");
+            str = "/home/user/.qexercise/Images/" + exerciseName + "1.png";
+            str.replace(QString(" "), QString(""));
+
+            if(!bild.load(str))
+            {
+                i = 1;
+                back();
+                return;
+            }
             bild = bild.scaled(w,h,Qt::KeepAspectRatio);
             lblInfo->setAlignment(Qt::AlignCenter);
             lblInfo->setPixmap(bild);
