@@ -48,6 +48,8 @@ void ListWindow::loadExercises(QString grp)
     group = grp;
     if(grp == "Cardio")
         list = xml->openCardio();
+    else if(grp == "Program")
+        list = xml->getPrograms();
     else
         list = xml->openGroup(grp);
 
@@ -55,7 +57,11 @@ void ListWindow::loadExercises(QString grp)
     lstExercises->setSelectionMode(QListView::SingleSelection);
     if(list.isEmpty())
     {
-        model->appendRow(new QStandardItem ("No exercises"));
+        if(grp == "Program")
+            model->appendRow(new QStandardItem ("No programs"));
+        else
+            model->appendRow(new QStandardItem ("No exercises"));
+
         lstExercises->setSelectionMode(QListView::NoSelection);
         return;
     }
@@ -70,11 +76,16 @@ void ListWindow::loadExercises(QString grp)
 
 void ListWindow::showInfo(QModelIndex index)
 {
-    if(index.data().toString() == "No exercises")
+    if(index.data().toString() == "No exercises" || index.data().toString() == "No programs")
         return;
 
-
-    if(group !=  "Cardio")
+    if(group == "Program")
+    {
+        piw = new ProgramInfoWindow(this);
+        piw->load(index.data().toString());
+        piw->show();
+    }
+    else if(group !=  "Cardio")
     {
         iw = new InfoWindow(this);
         connect(iw,SIGNAL(closed()),this,SLOT(sendClosed()));
