@@ -57,7 +57,7 @@ void XML::removeElement(QString name)
     file.close();
 }
 
-void XML::saveProgram(QString name, QList <QString> exercises)
+void XML::saveProgram(QString name, QModelIndexList exercises)
 {
     QDomDocument doc( "Program" );
     QString str = "/home/user/.qexercise";
@@ -87,7 +87,7 @@ void XML::saveProgram(QString name, QList <QString> exercises)
     return ;
 }
 
-QDomElement XML::createProgramNode(QDomDocument &d, QString name, QList <QString> exercises)
+QDomElement XML::createProgramNode(QDomDocument &d, QString name, QModelIndexList exercises)
 {
     QDomElement cn = d.createElement( "program" );
     QString tal;
@@ -98,7 +98,7 @@ QDomElement XML::createProgramNode(QDomDocument &d, QString name, QList <QString
         if(exercises.isEmpty())
             cn.setAttribute( "exercise" + tal, "" );
         else
-            cn.setAttribute( "exercise" + tal, exercises.takeFirst() );
+            cn.setAttribute( "exercise" + tal, exercises.takeFirst().data().toString() );
     }
 
     return cn;
@@ -151,6 +151,47 @@ QList <QString> XML::loadProgram(QString name)
     return readInfo;
 }
 
+QList <QString> XML::getPrograms()
+{
+    QList<QString> readInfo;
+    readInfo.clear();
+
+    QDomDocument doc( "Program" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/program.xml" );
+    if( !file.open( QIODevice::ReadOnly ) )
+    {
+        readInfo.append("file");
+      return readInfo;
+    }
+
+    doc.setContent(&file);
+    file.close();
+
+    QDomElement root = doc.documentElement();
+    if( root.tagName() != "programs" )
+    {
+        readInfo.append(root.tagName());
+        return readInfo;
+    }
+
+    QDomNode n = root.firstChild();
+    while( !n.isNull() )
+    {
+      QDomElement e = n.toElement();
+      if( !e.isNull() )
+      {
+        if( e.tagName() == "program" )
+        {
+          readInfo.append(e.attribute("name", ""));
+        }
+      }
+      n = n.nextSibling();
+   }
+
+    return readInfo;
+}
+
 void XML::saveSettings(QString vibrate, QString sound, QString volume,
                        QString set, QString reps1, QString reps2, QString reps3,
                        QString currentReps, QString min, QString sec, QString calories)
