@@ -19,8 +19,11 @@ public:
                    QString info);
     QList <QString> loadSettings();
     QList<QString> openAll();
-    void saveProgram(QString name, QList <QString> exercises);
+
+    void saveProgram(QString name, QModelIndexList exercises);
     QList <QString> loadProgram(QString name);
+    QList <QString> getPrograms();
+
     void updateLastWeight(QString name, QString weight, QString status, QString reps);
 
     void removeElement(QString name);
@@ -54,7 +57,7 @@ private:
     QDomElement createSettingsNode( QDomDocument &d, QString vibrate, QString sound, QString volume,
                                QString set, QString reps1, QString reps2, QString reps3, QString currentReps,
                                QString min, QString sec, QString calories);
-    QDomElement createProgramNode(QDomDocument &d, QString name, QList <QString> exercises);
+    QDomElement createProgramNode(QDomDocument &d, QString name, QModelIndexList exercises);
 };
 
 #endif // XML_H
